using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using Infragistics.Win.UltraWinGrid.ExcelExport;

namespace ExcelExporter
{
  public partial class Form1 : Form
  {
    private static DataTable tblCust;

    public Form1()
    {
      InitializeComponent();
    }

    private void Form1_Load(object sender, EventArgs e)
    {
      CreateCustomersTable();
      FillCustomersTable();

      ugExcel.DataSource = tblCust;
    }

    private void btnExport_Click(object sender, EventArgs e)
    {
      using (SaveFileDialog sfdXls = new SaveFileDialog())
      {
        sfdXls.RestoreDirectory = true;
        sfdXls.Title = "Save As";
        sfdXls.Filter = "Excel Files (*.xls)|*.xls|All files (*.*)|*.*";
        sfdXls.DefaultExt = "xls";
        sfdXls.FilterIndex = 1;

        // Display a file broweser dialog.

        if (sfdXls.ShowDialog() == DialogResult.OK)
        {
          try
          {
            using (UltraGridExcelExporter ugeXls = new UltraGridExcelExporter())
            {
              // Ty to export to the nominated file. Use this technique because it allows naming
              // of a Work Sheet.

              Infragistics.Documents.Excel.Workbook wb = new Infragistics.Documents.Excel.Workbook();
              Infragistics.Documents.Excel.Worksheet ws = wb.Worksheets.Add("Customers");

              if (uteAuthor.Text != String.Empty)
              {
                wb.DocumentProperties.Author = uteAuthor.Text;
              }

              if (uteTitle.Text != String.Empty)
              {
                wb.DocumentProperties.Title = uteTitle.Text;
              }

              ugeXls.Export(ugExcel, ws);
              wb.Save(sfdXls.FileName);

              MessageBox.Show(String.Format("The spreadsheet has been saved as '{0}'.", sfdXls.FileName), "Customers Spreadsheet",
                              MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
          }
          catch (Exception ex)
          {
            MessageBox.Show(String.Format("It was not possible to save the spreadsheet because:{0}{0}{1}", Environment.NewLine, ex.Message),
                            "Customers Spreadsheet", MessageBoxButtons.OK, MessageBoxIcon.Error);
          }
        }
      }
    }

    #region Set up data ...

    private static void CreateCustomersTable()
    {
      tblCust = new DataTable("customers");
      DataColumn col;

      col = new DataColumn("custID", typeof(int));
      tblCust.Columns.Add(col);

      tblCust.PrimaryKey = new DataColumn[] { col };

      col = new DataColumn("fname", typeof(string));
      tblCust.Columns.Add(col);

      col = new DataColumn("lname", typeof(string));
      tblCust.Columns.Add(col);

      col = new DataColumn("firstContact", typeof(DateTime));
      tblCust.Columns.Add(col);
    }

    private static void FillCustomersTable()
    {
      string[] names = {
								"Mike Finnigan",
								"Claudia Vanst",
								"Paul Forrest",
								"Dirk Spiggler",
								"Abraham Lincoln"
							};
      DateTime[] dates = {
								   DateTime.Now.AddYears( -2 ),
								   DateTime.Now.AddMonths( -1 ).AddMinutes( 19 ).AddSeconds( 2 ),
								   DateTime.Now.AddHours( -4 ).AddMinutes( 3 ).AddSeconds( 7 ),
								   DateTime.Now.AddDays( -1 ).AddMinutes( 123 ).AddSeconds( 12 ),
								   DateTime.Now.AddMonths( -1 ).AddMinutes( 19 ).AddSeconds( 3 )
							   };

      DataRow row;
      char[] delim = { ' ' };
      string[] name;

      for (int idx = 0; idx < names.Length; ++idx)
      {
        row = tblCust.NewRow();
        name = names[idx].Split(delim);

        row["custID"] = idx + 1;
        row["fname"] = name[0];
        row["lname"] = name[1];
        row["firstContact"] = dates[idx];

        tblCust.Rows.Add(row);
      }
    }

    #endregion


  }
}